ServerConfig

Struct ServerConfig 

pub struct ServerConfig {
    pub interface: Ipv4Addr,
    pub port: u16,
    pub broadcast_address: Ipv4Addr,
    pub max_apdu_length: u32,
    pub segmentation_supported: Segmentation,
    pub vendor_id: u16,
    pub cov_retry_timeout_ms: u64,
    pub on_time_sync: Option<Arc<dyn Fn(TimeSyncData) + Send + Sync>>,
    pub dcc_password: Option<String>,
    pub reinit_password: Option<String>,
    pub enable_fault_detection: bool,
}
Server configuration.

Fields

interface: Ipv4Addr

Local interface to bind.

port: u16

UDP port (default 0xBAC0 = 47808).

broadcast_address: Ipv4Addr

Directed broadcast address.

max_apdu_length: u32

Maximum APDU length accepted.

segmentation_supported: Segmentation

Segmentation support level.

vendor_id: u16

Vendor identifier.

cov_retry_timeout_ms: u64

Timeout in ms before retrying a failed confirmed COV notification send (default 3000ms).

on_time_sync: Option<Arc<dyn Fn(TimeSyncData) + Send + Sync>>

Optional callback invoked when a TimeSynchronization request is received.

dcc_password: Option<String>

Optional password required for DeviceCommunicationControl (Clause 16.4.1).

reinit_password: Option<String>

Optional password required for ReinitializeDevice (Clause 16.4.2).

enable_fault_detection: bool

Enable periodic fault detection / reliability evaluation (Clause 12). When true, the server evaluates analog objects every 10 s for OVER_RANGE / UNDER_RANGE faults.